Class: Yoti::DocScan::Session::Create::RequestedSupplementaryDocTextExtractionTaskBuilder

Inherits:
Object
  • Object
show all
Defined in:
lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb

Overview

Builder to assist creation of RequestedSupplementaryDocTextExtractionTask

Instance Method Summary collapse

Instance Method Details

#buildRequestedSupplementaryDocTextExtractionTask



86
87
88
89
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 86

def build
  config = RequestedSupplementaryDocTextExtractionTaskConfig.new(@manual_check)
  RequestedSupplementaryDocTextExtractionTask.new(config)
end

#with_manual_check_alwaysself

Requires that the Task is always followed by a manual TextDataCheck

Returns:

  • (self)


58
59
60
61
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 58

def with_manual_check_always
  @manual_check = Constants::ALWAYS
  self
end

#with_manual_check_fallbackself

Requires that only failed Tasks are followed by a manual TextDataCheck

Returns:

  • (self)


68
69
70
71
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 68

def with_manual_check_fallback
  @manual_check = Constants::FALLBACK
  self
end

#with_manual_check_neverself

The SupplementaryDocTextExtractionTask will never fallback to a manual TextDataCheck

Returns:

  • (self)


78
79
80
81
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 78

def with_manual_check_never
  @manual_check = Constants::NEVER
  self
end