Class: Yoti::DocScan::Session::Create::RequestedSupplementaryDocTextExtractionTaskBuilder
- Inherits:
-
Object
- Object
- Yoti::DocScan::Session::Create::RequestedSupplementaryDocTextExtractionTaskBuilder
- Defined in:
- lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb
Overview
Builder to assist creation of RequestedSupplementaryDocTextExtractionTask
Instance Method Summary collapse
- #build ⇒ RequestedSupplementaryDocTextExtractionTask
-
#with_manual_check_always ⇒ self
Requires that the Task is always followed by a manual TextDataCheck.
-
#with_manual_check_fallback ⇒ self
Requires that only failed Tasks are followed by a manual TextDataCheck.
-
#with_manual_check_never ⇒ self
The SupplementaryDocTextExtractionTask will never fallback to a manual TextDataCheck.
Instance Method Details
#build ⇒ RequestedSupplementaryDocTextExtractionTask
86 87 88 89 |
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 86 def build config = RequestedSupplementaryDocTextExtractionTaskConfig.new(@manual_check) RequestedSupplementaryDocTextExtractionTask.new(config) end |
#with_manual_check_always ⇒ self
Requires that the Task is always followed by a manual TextDataCheck
58 59 60 61 |
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 58 def with_manual_check_always @manual_check = Constants::ALWAYS self end |
#with_manual_check_fallback ⇒ self
Requires that only failed Tasks are followed by a manual TextDataCheck
68 69 70 71 |
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 68 def with_manual_check_fallback @manual_check = Constants::FALLBACK self end |
#with_manual_check_never ⇒ self
The SupplementaryDocTextExtractionTask will never fallback to a manual TextDataCheck
78 79 80 81 |
# File 'lib/yoti/doc_scan/session/create/requested_supplementary_doc_text_extraction_task.rb', line 78 def with_manual_check_never @manual_check = Constants::NEVER self end |