Class: Yoti::DocScan::Session::Create::RequestedTextExtractionTaskBuilder
- Inherits:
-
Object
- Object
- Yoti::DocScan::Session::Create::RequestedTextExtractionTaskBuilder
- Defined in:
- lib/yoti/doc_scan/session/create/requested_text_extraction_task.rb
Overview
Builder to assist creation of RequestedTextExtractionTask
Instance Method Summary collapse
- #build ⇒ RequestedTextExtractionTask
- #with_chip_data_desired ⇒ self
- #with_chip_data_ignore ⇒ self
-
#with_manual_check_always ⇒ self
Requires that the Task is always followed by a manual TextDataCheck.
-
#with_manual_check_fallback ⇒ self
Requires that only failed Tasks are followed by a manual TextDataCheck.
-
#with_manual_check_never ⇒ self
The TextExtractionTask will never fallback to a manual TextDataCheck.
Instance Method Details
#build ⇒ RequestedTextExtractionTask
108 109 110 111 |
# File 'lib/yoti/doc_scan/session/create/requested_text_extraction_task.rb', line 108 def build config = RequestedTextExtractionTaskConfig.new(@manual_check, @chip_data) RequestedTextExtractionTask.new(config) end |
#with_chip_data_desired ⇒ self
92 93 94 95 |
# File 'lib/yoti/doc_scan/session/create/requested_text_extraction_task.rb', line 92 def with_chip_data_desired @chip_data = Constants::DESIRED self end |
#with_chip_data_ignore ⇒ self
100 101 102 103 |
# File 'lib/yoti/doc_scan/session/create/requested_text_extraction_task.rb', line 100 def with_chip_data_ignore @chip_data = Constants::IGNORE self end |
#with_manual_check_always ⇒ self
Requires that the Task is always followed by a manual TextDataCheck
64 65 66 67 |
# File 'lib/yoti/doc_scan/session/create/requested_text_extraction_task.rb', line 64 def with_manual_check_always @manual_check = Constants::ALWAYS self end |